translate.tools.poterminology.TerminologyExtractor

Package translate :: Package tools :: Module poterminology :: Class TerminologyExtractor |
[hide private]
[frames] | no frames]

# Class TerminologyExtractor

source code

Instance Methods | [hide private]
__init__(self, foldtitle=True, ignorecase=False, accelchars="", termlength=3, sourcelanguage="en", invert=False, stopfile=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
parse_stopword_file(self) | source code
clean(self, string) returns the cleaned string that contains the text to be matched | source code
stopmap(self, word) return case-mapped stopword for input word | source code
stopword(self, word, defaultset=frozenset()) return stoplist frozenset for input word | source code
addphrases(self, words, skips, translation, partials=True) adds (sub)phrases with non-skipwords and more than one word | source code
processunits(self, units, fullinputpath) | source code
extract_terms(self, create_termunit=create_termunit, inputmin=1, fullmsgmin=1, substrmin=2, locmin=2) | source code
filter_terms(self, terms, nonstopmin=1, sortorders=["frequency","dictionary","length"]) reduce subphrases from extracted terms | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, foldtitle=True, ignorecase=False, accelchars="", termlength=3, sourcelanguage="en", invert=False, stopfile=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)